<?php

namespace com\fwdekker\deathnotifier\mailer;

use com\fwdekker\deathnotifier\UserManager;


/**
 * An email to help a user verify their email address.
 */
class VerifyEmailEmail extends Email
{
    /**
     * A string identifying the type of email.
     */
    public const TYPE = "verify-email";

    /**
     * @var string The token to verify the email address with.
     */
    public string $token;


    /**
     * Constructs an email to help a user verify their email address.
     *
     * @param string $recipient the intended recipient of the email
     * @param string $token the token to verify the email address with
     */
    public function __construct(string $recipient, string $token)
    {
        $this->type = self::TYPE;
        $this->recipient = $recipient;

        $this->token = $token;
        $this->arg1 = $token;
    }


    public function getSubject(): string
    {
        return "Verify your email address";
    }

    public function getBody(array $config): string
    {
        $base_path = $config["server"]["base_path"];
        $verify_path = "$base_path?action=verify-email&email=" . rawurlencode($this->recipient) . "&token=$this->token";

        return
            "You requested a new verification link for your Death Notifier account. " .
            "You can verify your email address by clicking the link below. " .
            "This link will expire after " . UserManager::MINUTES_VALID_VERIFICATION . " minutes. " .
            "Until you verify your email address, you will not receive any notifications." .
            "\n" .
            "Verify: $verify_path" .
            "\n\n" .
            $base_path;
    }
}
